@@ -139,6 +139,53 @@ fn apply_new_column() {
     assert_eq!(got, expected);
 }
 
+#[test]
+fn apply_currencytonum() {
+    let wrk = Workdir::new("apply");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["money"],
+            svec!["$10.00"],
+            svec!["$-10.00"],
+            svec!["$5"],
+            svec!["0"],
+            svec!["5"],
+            svec!["$0.25"],
+            svec!["$ 10.05"],
+            svec!["¥10,000,000.00"],
+            svec!["£423.56"],
+            svec!["€120.00"],
+            svec!["֏99,999.50"],
+            svec!["€300 999,55"],
+            svec!["This is not money. Leave untouched."],
+            svec!["₱1,234,567.89"],
+        ],
+    );
+    let mut cmd = wrk.command("apply");
+    cmd.arg("currencytonum").arg("money").arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["money"],
+        svec!["10.00"],
+        svec!["-10.00"],
+        svec!["5.00"],
+        svec!["0"],
+        svec!["5.00"],
+        svec!["0.25"],
+        svec!["10.05"],
+        svec!["10000000.00"],
+        svec!["423.56"],
+        svec!["120.00"],
+        svec!["99999.50"],
+        svec!["300999.55"],
+        svec!["This is not money. Leave untouched."],
+        svec!["1234567.89"],
+    ];
+    assert_eq!(got, expected);
+}
+
 #[test]
 fn apply_emptyreplace() {
     let wrk = Workdir::new("apply");
@@ -290,4 +337,70 @@ fn apply_datefmt_fmtstring_notime() {
         svec!["This is not a date and it will not be reformatted"],
     ];
     assert_eq!(got, expected);
-}
\ No newline at end of file
+}
+
+#[test]
+fn apply_geocode() {
+    let wrk = Workdir::new("apply");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["Location"],
+            svec!["40.812126, -73.9041813"],
+            svec!["40.66472342, -73.93867227"],
+            svec!["( 40.766672, -73.9568128 )"],
+            svec!["(40.819342, -73.9532127)"],
+            svec!["This is not a Location and it will not be geocoded"],
+            svec!["95.213424, 190,1234565"], // invalid lat, long
+        ],
+    );
+    let mut cmd = wrk.command("apply");
+    cmd.arg("geocode").arg("Location").arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Location"],
+        svec!["The Bronx, New York"],
+        svec!["Brooklyn, New York"],
+        svec!["Manhattan, New York"],
+        svec!["Edgewater, New Jersey"],
+        svec!["This is not a Location and it will not be geocoded"],
+        svec!["95.213424, 190,1234565"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn apply_geocode_fmtstring() {
+    let wrk = Workdir::new("apply");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["Location"],
+            svec!["40.812126, -73.9041813"],
+            svec!["40.66472342, -73.93867227"],
+            svec!["( 40.766672, -73.9568128 )"],
+            svec!["(40.819342, -73.9532127)"],
+            svec!["This is not a Location and it will not be geocoded"],
+            svec!["95.213424, 190,1234565"],
+        ],
+    );
+    let mut cmd = wrk.command("apply");
+    cmd.arg("geocode")
+        .arg("Location")
+        .arg("--formatstr")
+        .arg("county-country")
+        .arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Location"],
+        svec!["Bronx, US"],
+        svec!["Kings County, US"],
+        svec!["New York County, US"],
+        svec!["Bergen County, US"],
+        svec!["This is not a Location and it will not be geocoded"],
+        svec!["95.213424, 190,1234565"],
+    ];
+    assert_eq!(got, expected);
+}
